# Copyright (C) 2009-2010 Red Hat, Inc.
#
# This program is free software; you can redistribute
# it and/or modify it under the terms of version 2 of the
# GNU General Public License as published by the
# Free Software Foundation.

# -*- coding: utf-8 -*-
"""Separated encapsulations of common strings and short sentences."""

from pylons.i18n import lazy_ugettext as l_
# Imported, but not in module's header: tg (tmpl_context)

__all__ = ['Title', 'FlashMsg']


class Title:
    """Strings used in the title of the page.

    Final form of the title adjusted by 'luci.templates.title'.

    """

    @classmethod
    def usePart(cls, what, *args):
        """Adds/updates strings + theirs args to be used within page's title."""

        from tg import tmpl_context

        title_part = getattr(cls, what, ('', ))
        if type(title_part) is not tuple:
            if issubclass(type(title_part), basestring):
                title_part = (title_part,)
            else:
                title_part = ('', )

        tmpl_context.title_list.append(title_part[0])

        min_len = len(args)
        if min_len > len(title_part)-1:
            min_len = len(title_part)-1

        for i in xrange(1, min_len+1):
            tmpl_context.title_args[unicode(title_part[i])] = args[i-1]


    # Following pairs are used for general items listing or certain entity
    # details displaying (thus, the '{word}' is alias for the name of such
    # entity, 'word' itself is the next item in corresponding tuple and
    # is used as a key for storing/retrieving such string parameters
    # to separated dict respectively.

    CLUSTERS = l_('clusters')
    CERTAIN_CLUSTER = l_('cluster {cluster}'), 'cluster'

    CLUSTER_CREATE = l_('create cluster')
    CLUSTER_ADD_EXISTING = l_('add an existing cluster')

    GLOBAL_RES = l_('resources')
    CERTAIN_GLOBAL_RES = l_('resource {global_res}'), 'global_res'

    NODES = l_('nodes')
    CERTAIN_NODE = l_('node {node}'), 'node'

    SERVICES = l_('services')
    CERTAIN_SERVICE = l_('service {service}'), 'service'

    FAILOVERS = l_('failovers')
    CERTAIN_FAILOVER = l_('failover {failover}'), 'failover'

    FENCES = l_('fences')
    CERTAIN_FENCE = l_('fence {fence}'), 'fence'


class FlashMsg:
    """Strings used for error/warning/notice reporting to the user."""

    STYLE_WARNING = 'warning'
    STYLE_ERROR = 'error'

    # Pairs of message and the message status to be used by tg.flash method.

    # Connected with
    BAD_COMMAND_REQUEST = l_('Bad command request.'), STYLE_WARNING
    INTERNAL_ERROR = l_('Internal error.'), STYLE_ERROR
    NOTHING_CHOSEN = l_('Nothing was chosen.'), STYLE_WARNING

    # Connected with decorators.

    UNSUPPORTED_METHOD = l_('%s method not supported in this context.'), STYLE_ERROR

